@@ -7,7 +7,7 @@ use MooseX::Types -declare => [ qw(
 ) ];
 use autodie;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 # Get the DEBUG constant from $Data::FlexSerializer::DEBUG or
 # $ENV{DATA_FLEXSERIALIZER_DEBUG}
@@ -142,6 +142,14 @@ sub serialize {
     ));
   }
 
+  if ($output_format eq 'sereal' && !$self->{sereal_encoder}) {
+    # We don't use the sereal_encoder accessor here for speed, and
+    # since output_format is rw someone may change this to 'sereal'
+    # dynamically, in which case we'll have to construct a new
+    # emitter.
+    $self->sereal_encoder;
+  }
+
   my @out;
   foreach my $data (@_) {
     my $serialized = $output_format eq 'json'
@@ -339,7 +347,7 @@ __END__
 
 =head1 NAME
 
-Data::FlexSerializer - (De-)serialization from/to (compressed) JSON or Storable
+Data::FlexSerializer - (De-)serialization from/to (compressed) JSON, Storable or Sereal
 
 =head1 SYNOPSIS
 
@@ -477,6 +485,12 @@ C<storable> or C<sereal>.  It has the obvious effect. Its value can be
 changed at runtime via the accessor to facilitate having certain
 output formats in experiments.
 
+Note that if you dynamically change this to C<sereal> at runtime the
+first call to L</serialize> after that will dynamically construct a
+L<Sereal::Encoder> object, to avoid this supply a custom
+L</sereal_encoder> object when constructing the object, and we won't
+have to construct it dynamically later.
+
 =head3 detect_storable
 
 C<detect_storable>, if set, forces C<Data::FlexSerializer> into
